@@ -7,7 +7,7 @@ use Carp ();
 use Ref::Util qw( is_ref is_plain_arrayref is_plain_hashref );
 
 # ABSTRACT: C data types for FFI
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 our %ffi;
@@ -150,7 +150,7 @@ FFI::C - C data types for FFI
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -245,6 +245,9 @@ This distribution provides tools for building classes to interface for common C
 data types.  Arrays, C<struct>, C<union> and nested types based on those are
 supported.
 
+To work with C APIs that work with C file pointers you can use
+L<FFI::C::File> and L<FFI::C::PosixFile>.
+
 =head1 METHODS
 
 =head2 ffi
@@ -398,6 +401,8 @@ So-called "pass-by-value" is not and will not be supported.  For
 
 =item L<FFI::C::File>
 
+=item L<FFI::C::PosixFile>
+
 =item L<FFI::C::Struct>
 
 =item L<FFI::C::StructDef>
